@@ -1,9 +1,9 @@
 from dataclasses import dataclass
 
 from ..soap.soap_configuration import SoapConfiguration
-from ....domain.authentication.basic import BasicAuthentication
+from ....domain.authentication.basic import ConnectionBasicAuthentication
 from ....domain.enums import ConnectionTypes, ConnectorTypes
-from ....domain.server.base import Server
+from ....domain.server.base import ConnectionServer
 
 
 @dataclass
@@ -11,7 +11,7 @@ class WebServiceConnectionConfiguration:
     Name: str = None
     ConnectionType: ConnectionTypes = None
     ConnectorType: ConnectorTypes = None
-    Server: Server = None
+    Server: ConnectionServer = None
     Soap: SoapConfiguration = None
-    BasicAuthentication: BasicAuthentication = None
+    BasicAuthentication: ConnectionBasicAuthentication = None
     Ssl: bool = False
